<?php

/**
 * This is the model class for table "usuarios".
 *
 * The followings are the available columns in table 'usuarios':
 * @property integer $id
 * @property string $nombre
 * @property string $apellido
 * @property string $documento
 * @property string $direccion
 * @property integer $idGenero
 * @property integer $idProfesion
 */
class Usuario extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @return Usuario the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'usuarios';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('nombre, apellido, documento, direccion, idGenero, idProfesion', 'required'),
			array('idGenero, idProfesion', 'numerical', 'integerOnly'=>true),
			array('nombre, apellido, direccion', 'length', 'max'=>250),
			array('documento', 'length', 'max'=>20),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, nombre, apellido, documento, direccion, idGenero, idProfesion', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(

			'genero'=>array(self::BELONGS_TO,'Genero','idGenero'),
			'profesion'=>array(self::BELONGS_TO,'Profesion','idProfesion'),
			'idiomas'=>array(self::MANY_MANY,'Idioma', 'usuarios_idiomas(id_usuarios,id_idiomas)'),

		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'nombre' => 'Nombre',
			'apellido' => 'Apellido',
			'documento' => 'Documento',
			'direccion' => 'Direccion',
			'idGenero' => 'Id Genero',
			'idProfesion' => 'Id Profesion',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('nombre',$this->nombre,true);
		$criteria->compare('apellido',$this->apellido,true);
		$criteria->compare('documento',$this->documento,true);
		$criteria->compare('direccion',$this->direccion,true);
		$criteria->compare('idGenero',$this->nombre);
		$criteria->compare('idProfesion',$this->nombre);

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}
}